function [res] = modelo_ead(t,v, vp, rpar)
    %% Parametros

    fPar = rpar(1:7);
    mPar = rpar(8:end);

    M_H2O   = fPar(1);
    M_EtOH  = fPar(2);
    R       = fPar(3);  %    8.314598;       % R - gas constant [J/(K mol)]
    Mfw     = fPar(4);  %    0.182;          % Mfw - Molar Fraction of Water [%] 
    Ff      = fPar(5);  %    20410/3600;     % Ff - Feed flow rate [kg/s]
    Tf      = fPar(6);  %    440;            % Tf - Feed Temperature [K]
    Pf      = fPar(7);  %    379212          % Pf - Feed Pressure [Pa]
    A       = mPar(3);  % A - Tower area [m^2]
    e       = mPar(4);  % e - Gas void fraction []
    eb      = mPar(5);
    Q       = mPar(6);
    cpg     = mPar(7);
    cps     = mPar(8);
    Dax     = mPar(9);  %    0.00113;        % Dax - Axial Effective Dispersion Coefficient [m^2 s^-1]
    kef     = mPar(10);
    Tb      = mPar(11);
    N       = mPar(13);
    dL      = mPar(14);     %     7.3/(100-1)     % dL - Length of sections between two discretized points [m]
    rhos    = mPar(15);     %729;            % ep - Bulk Density [kg/m3]
    qs      = mPar(17);     % qws - Water Saturation Capacity [mol/kg]
    Tref    = mPar(18);
    K0      = mPar(19);
    KDLF    = mPar(20); %1/s
    rp      = mPar(16);
    dp      = 2*rp;
    mug     = 1e-6;

    %% Alocacao
    
    q  = v(0*N+1:1*N);   dq = vp(0*N+1:1*N);
    c  = v(1*N+1:2*N);   dc = vp(1*N+1:2*N);
    T  = v(2*N+1:3*N);   dT = vp(2*N+1:3*N);
    C  = v(3*N+1:4*N);   dC = vp(3*N+1:4*N);
%     u  = v(3*N+1:4*N);   du = vp(3*N+1:4*N);
%     T  = v(4*N+1:5*N);   dT = vp(4*N+1:5*N);

    
    %res(1:5*N,1) = 0;
    res(1:4*N,1) = 0;
    
    %% Equacoes auxiliares ================================================
    Mf = c./C;
    P = C*(R*Tf);
    C0 = Pf/R/Tf;
    
    % Isoterma
    K = K0*exp(Q/R*(1./T-1/Tref)); % 1/Pa
   % qeq = qs*K.*Pf.*Mf./(1 + K.*Pf.*Mf); % mol/kg 
    qeq = qs*K.*P.*Mf./(1 + K.*P.*Mf); % mol/kg 
   % qeq = qs*K.*Pf*Mfw./(1 + K.*Pf*Mfw).*ones(N,1); % mol/kg

    % Massa especifica da fase gas
    rhof0 = Pf*(Mfw*M_H2O + (1-Mfw)*M_EtOH)/(R*Tf); % kg/m3
    
    % Massa especifica da fase gas
    rhof = P.*(Mf*M_H2O + (1-Mf)*M_EtOH)./(R*T);
    %rhof = Pf.*(Mf*M_H2O + (1-Mf)*M_EtOH)./(R*Tf);
 %   rhof = Pf*(((Mfw))*M_H2O + (1-(Mfw))*M_EtOH)./(R*T);
    
    % Velocidade media
     uf = (Ff/(rhof0*A))* ones(numel(Ff./(rhof.*A)),1);%./(rhof.*A);
     u = uf;
    % uf = (Ff./(rhof*A));%./(rhof.*A);
     uf0 = (Ff./(rhof0*A));

    % y0 = (uf0*Mfw + (1*Dax/dL - uf0/2)*y(1))/(uf0/2 + 1* Dax/dL);
    % psi = (rhof*cpg+(1/e-1)*rhos*cps);
    
    
    %% Equacoes diferenciais ==============================================
    % ---------------------------------------------------------------------
    % Balanco de massa da agua na fase solida 
    % ---------------------------------------------------------------------
    res(0*N+1:1*N) = dq - KDLF*(qeq - q); % mol/(kg.s)
    
    % ---------------------------------------------------------------------
    % Balanco de massa para a agua na fase fluida 
    % ---------------------------------------------------------------------
  
    % Termo fonte
    Sc = 1*(1/e-1)*rhos.*dq; % mol/(m3.s)
    
    % Residuo do primeiro volume
    res(1*N+1) = dc(1)-(Dax/dL^2)*(c(2)-c(1)) - Ff*0.08/M_H2O/A/dL + 1/(e*dL)*u(1)*c(1) + Sc(1);
    %res(1*N+1) = dc(1)-(Dax/dL^2)*(c(2)-c(1)) - (Ff*0.08/M_H2O/A) + 1/(e*dL)*u(1)*c(1) + Sc(1);

    % Residuo dos volumes internos
    for i = 1*N+2:2*N-1
       j = i-1*N;
       res(i) = dc(j)-(Dax/dL^2*(c(j+1)-2*c(j)+c(j-1))-(1/e/dL)*(u(j)*c(j)-u(j-1)*c(j-1)) + Sc(j)); 
    end
    
    % Residuo do ultimo volume
    res(2*N) = dc(N) + (Dax/dL^2)*(c(N)-c(N-1)) + (1/e/dL)*(u(N)*c(N)-u(N-1)*c(N-1)) + Sc(N);

%     % ---------------------------------------------------------------------
%     % Conservacao dos momentos (Correlao de Ergun)
%     % ---------------------------------------------------------------------
% 
%     % Termo fonte
%     Sp = 1*(1.75*(1-eb)*rhof/eb^3/dp.*abs(u).*u +...
%          150*mug*(1-eb)^2/eb^3/dp^3*u);
%      
%     % Residuo do primeiro volume
%     res(3*N+1) = -P(1) + Pf + dL*Sp(1);
%    
%     % Residuo dos demais volumes
%     for i = 3*N+2:4*N
%         j = i-3*N;
%         res(i) = P(j) - P(j-1) - dL*Sp(j);
%     end
%     
    % ---------------------------------------------------------------------
    % Conservacao de Energia
    % ---------------------------------------------------------------------

    alpha = kef./(rhof*cpg + (1/e-1)*rhos*cps);
    beta = u.*rhof*cpg./(e*rhof*cpg+(1-e)*rhos*cps);
    gamma = Q*(1-e)*rhos./(e*rhof*cpg + (1-e)*rhos*cps);
       
    % Residuo do primeiro volume
    res(2*N+1) = -dT(1) + 1/dL^2*(alpha(1)*(T(2)-T(1)) - beta(1)*T(1)) + beta(1)*e*Tf/dL - gamma(1)*dq(1);
   
    % Residuo dos demais volumes
    for i = 2*N+2:3*N-1
        j = i-2*N;
        res(i) = -dT(j) + alpha(j)/dL^2*(T(j+1)-2*T(j)+T(j-1)) - beta(j)/dL*(T(j)-T(j-1)) - gamma(j)*dq(j);
    end
    
    res(3*N) = -dT(N) - alpha(N)/dL^2*(T(N)-T(N-1)) - beta(N)/dL*(T(N)-T(N-1)) - gamma(N)*dq(N);
    
    
    % ---------------------------------------------------------------------
    % Balanco de Massa global
    % ---------------------------------------------------------------------
    
    % Termo fonte
    SC = 1*(1/e-1)*rhos*dq;
    
    % Residuo do primeiro volume
    res(3*N+1) = dC(1) - 1*(-1/e/dL*(u(1)*C(1)- C0*uf0)+SC(1));
    
    % Residuo dos volumes internos e ultimo volume
    for i = 3*N+2:4*N;
        j = i-3*N;
        res(i) = dC(j) - 1*(-1/e/dL*(u(j)*C(j)-u(j-1)*C(j-1))+SC(j));
    end
     
end