%function psa_teste_ead

close all; clear all; clc;

%% Feed Parameters:
MmH2O = 18*1e-3;    % MmH2O - Water Molar Mass [g/mol] 
MmC2H6O = 46*1e-3;  % MmC2H6O - Ethanol Molar Mass [g/mol]
R = 8.314598;       % R - gas constant [J/(K mol)]
Mfw = 0.182;        % Mfw - Molar Fraction of Water [%] 
Ff = 20410/3600*100;    % Ff - Feed flow rate [kg/s]
Tf = 440;           % Tf - Feed Temperature [K]
Pf = 379212;        % Pf - Feed Pressure [Pa]
fPar = [MmH2O;MmC2H6O;R;Mfw;Ff;Tf;Pf];

%% Model Parameters:
L = 7.3;            % L - Tower length [m]
D = 2.4;            % D - Tower diameter [m]
A = pi*D^2/4;       % A - Tower area [m^2]
e = 0.63;           % e - Gas void fraction []
eb = 0.4;           % eb - Bulk void fraction []
Q = 51900;          % Q - Isosteric heat of adsorption [mol^-1]
cpg = 1000;         % cpg - Thermal Capacity of Gas [J (kg K)^-1]
cps = 1260;         % cps - Thermal Capacity of Solid (Zeolite) [J (kg K)^-1]
Dax = 0.00113;      % Dax - Axial Effective Dispersion Coefficient [m^2 s^-1]
kef = 41.26;        % kef - Effective Thermal Conductivity [W (m K)^-1]
Tb = 450;           % Tb - Initial Bed Temperature [K]
N = 50;            % N - Number of points along the beds axial length
dL = L/(N);       % dL - Length of sections between two discretized points [m]
%dL = 1/(N-1);      % dL - Length of sections between two discretized points [m]
rhos = 729;         % rho_s - Bulk Density [kg/m3]
rp = 0.0015875;     % rp - Adsorbent Particle Radius [m]
qws = 10.6656;      % qws - Water Saturation Capacity [mol/kg] - 17
T0 = 323;           % T0 - Reference Temperature [K]
K0 = 0.0441765;     % K0 - Equilibrium Constant @ Reference Temperature [Pa^-1]
KLDF = 0.5E-4;%0.5E-4;      % KLDF - Linear Driving Force Mass Transfer Coefficient [s^-1]
mPar = [L;D;A;e;eb;Q;cpg;cps;Dax;kef;Tb;R;N;dL;rhos;rp;qws;T0;K0;KLDF];
rpar = [fPar;mPar];

timespan = [0 1e7] ; 

rhof0 = Pf*(Mfw*MmH2O + (1-Mfw)*MmC2H6O)/(R*Tf);
uf0 = (Ff/(rhof0*A));

ci(1:N) = zeros(N,1);
ci(N+1:2*N)   = 0;%(Ff*0.08/MmH2O/A/uf0);
ci(2*N+1:3*N) = Tf;%
ci(3*N+1:4*N) = Pf/R/Tf;
% ci(3*N+1:4*N) = (Ff./(rhof0*A));
% ci(4*N+1:5*N) = Tb;

yp0 = zeros(4*N,1);

opt = odeset('RelTol',2e-3,'AbsTol',3e-3);
[t,Y] = ode15i(@modelo_ead,timespan,ci,yp0,opt,rpar);

[n,m] = size(Y);
z = linspace(0,L,N);


q = Y(:,0*N+1:1*N);    
c = Y(:,1*N+1:2*N);
T = Y(:,2*N+1:3*N);
C = Y(:,3*N+1:4*N);

t = linspace(0,t(end),numel(q(:,N/2)));
t2 = linspace(0,t(end),numel(c(:,N/2)));


figure;
%for i = 1:numel(q(1,:))
%plot(t/3600/24,q(:,N/2),'-'); hold on;
plot(t/3600/24,q(:,N/2),'-'); hold on;
% plot(q(:,1),'-');
% plot(q(:,N),'-');
%end
xlim([0 t(end)/3600/24])
ylabel('q [mol/kg]');
xlabel('t [dias]');
%title('\it{Breakthrough Curve}');


% figure;
% for i = 1:numel(q(:,1))
%     plot(q(i,numel(q(1,:)/2))); hold on;
% end
% ylabel('q [mol/kg]');
% xlabel('t');

figure;
for i = 1:numel(c(:,1))
    plot(c(i,:)); hold on;
end
ylabel('c_{H_2 O} [mol/m^3]');
xlabel('N');
%legend(time);

figure;
%for i = 1:numel(c(:,1))
    plot(t,c(:,1)/(Ff*0.08/MmH2O/uf0/A)); hold on;
    plot(t,c(:,N/2)/(Ff*0.08/MmH2O/uf0/A)); hold on;
    plot(t,c(:,N)/(Ff*0.08/MmH2O/uf0/A)); hold on;
%end
legend(num2str(timespan));
ylabel('c_{H_2 O} [mol/m^3]');
xlabel('t');

figure;
for i = 1:numel(T(:,1))
    plot(T(i,:)); hold on;
end
ylabel('T [K]');
xlabel('N');

figure;
%for i = 1:numel(q(1,:))
    plot(t,T(:,1),'-'); hold on;
    plot(t,T(:,N/2),'-'); hold on;
    plot(t,T(:,N),'-'); hold on;
%end
xlim([0 t(end)])
ylabel('T [K]');
xlabel('t [s]');
%title('\it{Breakthrough Curve}');
% 
% figure;
% for i = 1:numel(C(:,1))
%     plot(C(i,:)); hold on;
% end
% ylabel('C_{TOT} [mol/m^3]');
% xlabel('N');
% 
% figure;
% for i = 1:numel(C(:,1))
%     plot(c(i,:)./C(i,:)); hold on;
% end
% ylabel('c_a/C_{TOT} [mol/mol]');
% xlabel('N');


% figure;
% plot(t/3600/24,c(:,N/2)./C(:,N/2)); hold on;
% xlim([0 t(end)/3600/24])
% ylabel('c/C [mol/mol]');
% xlabel('t [days]');
% title('\it{Molar Fraction}');
% 

% figure;
% for i = 1:numel(T(:,1))
%     plot(T(i,:)); hold on;
% end
% 
% figure;
% for i = 1:numel(P(:,1))
%     plot(P(i,:)); hold on;
% end

% figure;
% for i = 1:numel(c(:,1))
%     plot(c(i,:)); hold on;
% end
% ylabel('c');
% T = Y(:,2*N+1:3*N);   
% P = Y(:,3*N+1:4*N);  
% uf = Y(:,4*N+1:5*N);
% C = Y(:,5*N+1:6*N);
% timeVect = (0:1:N-1)*dL+0.5*dL;

% adsorpFinVol.y = y;         
% adsorpFinVol.q = q;  
% adsorpFinVol.T = T;   
% adsorpFinVol.P = P;  
% adsorpFinVol.uf = uf;
% adsorpFinVol.timeVect = timeVect;
% 
% save('varsFinVol_CC2.mat', '-struct', 'adsorpFinVol');

% newT = zeros(numel(T(:,1)),numel(T(1,:)));
% timeVect = 0:dL:L;
% timeVectInterpol = timeVect(1:end-1)+0.5;
% for i = 1:numel(T(:,1))
%     pol_T = polyfit(timeVectInterpol,T(i,1:end),numel(timeVectInterpol)-1);
%     newT(i,:) = polyval(pol_T,timeVect);
% end
% t = q(q(:,end)<=qws);
% size(t)
% size(q)
% time(size(t))

% perfil na fase solida
% for i = 1:m
%     plot(z,q(i,:))
%     getframe;
%     ylim([0 11])
% end
% figure;
% plot(z,y)
% xlabel('L [m]');
% ylabel('y[%]');
% title('Frao Molar de gua na Fase Gasosa');
% axis([0 L (min(min(y))) (max(max(y)))]);
% 
% figure;
% plot(z,q)
% xlabel('L [m]');
% ylabel('q [%]');
% title('Frao Molar de gua na Fase Slida');
% axis([0 L (min(min(q))) (max(max(q)))]);
% 
% figure;
% %plot(timeVect,T)
% plot(1:numel(T),T);
% xlabel('L [m]');
% ylabel('T [K]');
% title('Variao de Temperatura ao longo do Leito');
%axis([0 L (min(min(T))) (max(max(T)))]);
%axis(timeVect);

% 
% figure;
% plot(z,P/1000)
% xlabel('L [m]');
% ylabel('P [kPa]');
% title('Queda de Presso ao longo do Leito');
% axis([0 L (min(min(P))/1000) (max(max(P))/1000)]);
% 
% figure;
% plot(z,uf)
% xlabel('L [m]');
% ylabel('u [m/s]');
% title('Variao de Velocidade ao longo do Leito');
% axis([0 L (min(min(uf))) (max(max(uf)))]);
% 
% % figure;
% % plot(z,y(end,1:N))
% 
% figure;
% plot(t/60,T(:,50));
% xlabel('Tempo [min]');
% ylabel('T [K]');
% xlim([0 t(end)/60]);
% title('Temperatura ao Longo da Coluna');


% Perfil de Temperatura
% figure;
% for i = 1:m
%     plot(z,T(i,:))
%     ylim([450 500])
%     getframe;
% end


% 
% figure;
% for i = 1:n
%     plot(z,y(i,N+1:2*N));
%     title('Molar Loading in Adsorbed Phase');
%     xlim([0 L]);
%     ylim([0 11]);
%     xlabel('L [m]');
%     ylabel('q [mol/kg]');
%     getframe;
% end



%end